==> ember-cli-3.13.0.tgz: package/README.md <==

ember-cli
==============================================================================

[![Latest npm release][npm-badge]][npm-badge-url]
[![TravisCI Build Status][travis-badge]][travis-badge-url]
[![AppVeyor Build Status][appveyor-badge]][appveyor-badge-url]
[![Test Coverage][coveralls-badge]][coveralls-badge-url]
[![Code Climate][codeclimate-badge]][codeclimate-badge-url]

[logo]: https://avatars0.githubusercontent.com/u/10262982?v=3&s=150
[npm-badge]: https://img.shields.io/npm/v/ember-cli.svg
[npm-badge-url]: https://www.npmjs.com/package/ember-cli
[travis-badge]: https://img.shields.io/travis/ember-cli/ember-cli/master.svg?label=TravisCI
[travis-badge-url]: https://travis-ci.org/ember-cli/ember-cli
[appveyor-badge]: https://img.shields.io/appveyor/ci/embercli/ember-cli/master.svg?label=AppVeyor
[appveyor-badge-url]: https://ci.appveyor.com/project/embercli/ember-cli/branch/master
[coveralls-badge]: https://img.shields.io/coveralls/ember-cli/ember-cli/master.svg
[coveralls-badge-url]: https://coveralls.io/github/ember-cli/ember-cli
[codeclimate-badge]: https://codeclimate.com/github/ember-cli/ember-cli/badges/gpa.svg
[codeclimate-badge-url]: https://codeclimate.com/github/ember-cli/ember-cli

The Ember.js command line utility.


Features
------------------------------------------------------------------------------

- Asset build pipeline using [Broccoli.js](https://broccoli.build/)
- ES6 transpilation using [Babel](https://babeljs.io/)
- Project structure conventions using ES6 module syntax
- Development server including live-reload and API proxy
- File/Project generator using blueprints
- Unit, Integration and Acceptance test support using
  [Testem](https://github.com/testem/testem)
- Powerful addon system for extensibility


Installation
------------------------------------------------------------------------------

```
npm install -g ember-cli
```

Usage
------------------------------------------------------------------------------

After installation the `ember` CLI tool will be available to you. It is the
entrypoint for all the functionality mentioned above.

You can call `ember <command> --help` to find out more about all of the
following commands or visit <https://cli.emberjs.com/release/> to read
the in-depth documentation.


Documentation
------------------------------------------------------------------------------
Please refer to the [CLI guides](https://cli.emberjs.com/release/) for help using Ember CLI.

Contributing
------------------------------------------------------------------------------
Please see the [contributing guidelines](https://github.com/ember-cli/ember-cli/blob/master/CONTRIBUTING.md)


Community
------------------------------------------------------------------------------

- Discord: [Get your invite](https://discordapp.com/invite/zT3asNS)
- Issues: [ember-cli/issues](https://github.com/ember-cli/ember-cli/issues)
- Documentation: [ember-cli.com](https://cli.emberjs.com/release/)



License
------------------------------------------------------------------------------

This project is licensed under the [MIT License](LICENSE).

==> ember-cli-4.0.1.tgz: package/README.md <==

ember-cli
==============================================================================

[![Latest npm release][npm-badge]][npm-badge-url]
[![GitHub Actions CI][github-actions-badge]][github-actions-ci-url]
[![Test Coverage][coveralls-badge]][coveralls-badge-url]
[![Code Climate][codeclimate-badge]][codeclimate-badge-url]

[logo]: https://avatars0.githubusercontent.com/u/10262982?v=3&s=150
[npm-badge]: https://img.shields.io/npm/v/ember-cli.svg
[npm-badge-url]: https://www.npmjs.com/package/ember-cli
[coveralls-badge]: https://img.shields.io/coveralls/ember-cli/ember-cli/master.svg
[coveralls-badge-url]: https://coveralls.io/github/ember-cli/ember-cli
[codeclimate-badge]: https://codeclimate.com/github/ember-cli/ember-cli/badges/gpa.svg
[codeclimate-badge-url]: https://codeclimate.com/github/ember-cli/ember-cli
[github-actions-badge]: https://github.com/ember-cli/ember-cli/workflows/CI/badge.svg
[github-actions-ci-url]: https://github.com/ember-cli/ember-cli/actions?query=workflow%3ACI

The Ember.js command line utility.


Features
------------------------------------------------------------------------------

- Asset build pipeline using [Broccoli.js](https://broccoli.build/)
- ES6 transpilation using [Babel](https://babeljs.io/)
- Project structure conventions using ES6 module syntax
- Development server including live-reload and API proxy
- File/Project generator using blueprints
- Unit, Integration and Acceptance test support using
  [Testem](https://github.com/testem/testem)
- Powerful addon system for extensibility


Installation
------------------------------------------------------------------------------

```
npm install -g ember-cli
```

Usage
------------------------------------------------------------------------------

After installation the `ember` CLI tool will be available to you. It is the
entrypoint for all the functionality mentioned above.

You can call `ember <command> --help` to find out more about [all of the
following commands](https://cli.emberjs.com/release/basic-use/cli-commands/) or visit <https://cli.emberjs.com/release/> to read
the in-depth documentation.


Documentation
------------------------------------------------------------------------------
Please refer to the [CLI guides](https://cli.emberjs.com/release/) for help using Ember CLI.

Contributing
------------------------------------------------------------------------------
Please see the [contributing guidelines](https://github.com/ember-cli/ember-cli/blob/master/CONTRIBUTING.md)


Community
------------------------------------------------------------------------------

- Discord: [Get your invite](https://discord.gg/emberjs)
- Issues: [ember-cli/issues](https://github.com/ember-cli/ember-cli/issues)
- Documentation: [ember-cli.com](https://cli.emberjs.com/release/)



License
------------------------------------------------------------------------------

This project is licensed under the [MIT License](LICENSE).
